@@ -1,4 +1,4 @@
-import { permissionCheckingRouter, simpleGetList } from '@tamanu/shared/utils/crudHelpers';
+import { getResourceList, permissionCheckingRouter } from '@tamanu/shared/utils/crudHelpers';
 import asyncHandler from 'express-async-handler';
 import { getPotentialInvoiceItems } from './getPotentialInvoiceItems';
 import { transform, set } from 'lodash';
@@ -7,7 +7,31 @@ export const invoiceItemsRoute = permissionCheckingRouter('read', 'Invoice');
 
 invoiceItemsRoute.get(
   '/:id/items',
-  simpleGetList('InvoiceItem', 'invoiceId', { skipPermissionCheck: true }),
+  asyncHandler(async (req, res) => {
+    const { models, params } = req;
+    const invoiceId = params.id;
+    const invoice = await models.Invoice.findByPk(invoiceId);
+
+    if (!invoice) {
+      throw new Error(`Invoice not found: ${invoiceId}`);
+    }
+
+    const invoicePriceListId = await models.InvoicePriceList.getIdForPatientEncounter(
+      invoice.encounterId,
+    );
+
+    const associations = models.InvoiceItem.getListReferenceAssociations(
+      models,
+      invoicePriceListId,
+    );
+
+    const response = await getResourceList(req, 'InvoiceItem', 'invoiceId', {
+      skipPermissionCheck: true,
+      include: associations,
+    });
+
+    res.send(response);
+  }),
 );
 
 invoiceItemsRoute.get(
