@@ -1,5 +1,5 @@
 import { sub } from 'date-fns';
-import { toDateString } from '@tamanu/shared/utils/dateTime';
+import { toDateString } from '@tamanu/utils/dateTime';
 import { ENCOUNTER_TYPES } from '@tamanu/constants';
 
 import { makeDeletedAtIsNullFilter, makeFilter } from './query';
@@ -82,6 +82,7 @@ export const createPatientFilters = filterParams => {
       }),
     ),
     makeDeletedAtIsNullFilter('encounters'),
+    makeDeletedAtIsNullFilter('patients'),
   ].filter(f => f);
 
   return filters;
